summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHakan Olsson <ho@cvs.openbsd.org>2005-03-05 12:22:41 +0000
committerHakan Olsson <ho@cvs.openbsd.org>2005-03-05 12:22:41 +0000
commiteb91f017121b838b41efeb266f8c190b74b5360d (patch)
treeb870f9aa6c0761d522e41c80c14eb905c8c97e25
parent2ce3bda724c3ddae65ceb3a274431a8c7f825c34 (diff)
Add RFC3947 NAT-T vendor ID string. hshoexer@ ok.
-rw-r--r--sbin/isakmpd/nat_traversal.c17
1 files changed, 7 insertions, 10 deletions
diff --git a/sbin/isakmpd/nat_traversal.c b/sbin/isakmpd/nat_traversal.c
index 6b33329d114..53cd1ad77f2 100644
--- a/sbin/isakmpd/nat_traversal.c
+++ b/sbin/isakmpd/nat_traversal.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: nat_traversal.c,v 1.9 2005/02/27 13:12:12 hshoexer Exp $ */
+/* $OpenBSD: nat_traversal.c,v 1.10 2005/03/05 12:22:40 ho Exp $ */
/*
* Copyright (c) 2004 Håkan Olsson. All rights reserved.
@@ -49,20 +49,17 @@
#include "virtual.h"
/*
* XXX According to draft-ietf-ipsec-nat-t-ike-07.txt, the NAT-T
* capability of the other peer is determined by a particular vendor ID
* sent as the first message. This vendor ID string is supposed to be a
* MD5 hash of "RFC XXXX", where XXXX is the future RFC number.
*
* These seem to be the "well" known variants of this string in use by
* products today.
*/
static const char *isakmp_nat_t_cap_text[] = {
- "draft-ietf-ipsec-nat-t-ike-02\n", /* V2 */
- "draft-ietf-ipsec-nat-t-ike-03", /* V3 */
-#ifdef notyet
- "RFC XXXX",
-#endif
+ "draft-ietf-ipsec-nat-t-ike-02\n", /* draft, V2 */
+ "draft-ietf-ipsec-nat-t-ike-03", /* draft, V3 */
+ "RFC 3947"
};
/* In seconds. Recommended in draft-ietf-ipsec-udp-encaps-09. */
@@ -49,20 +49,17 @@
#include "virtual.h"
/*
- * XXX According to draft-ietf-ipsec-nat-t-ike-07.txt, the NAT-T
- * capability of the other peer is determined by a particular vendor ID
- * sent as the first message. This vendor ID string is supposed to be a
- * MD5 hash of "RFC XXXX", where XXXX is the future RFC number.
+ * NAT-T capability of the other peer is determined by a particular vendor
+ * ID sent in the first message. This vendor ID string is supposed to be a
+ * MD5 hash of "RFC 3947".
*
* These seem to be the "well" known variants of this string in use by